@@ -1,28 +1,14 @@
-#
 # Copyright (C) 2009, 2013, 2014 Red Hat, Inc.
 # Copyright (C) 2009 Cole Robinson <crobinso@redhat.com>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-# MA 02110-1301 USA.
-#
+# This work is licensed under the GNU GPLv2 or later.
+# See the COPYING file in the top-level directory.
 
-import logging
+from virtinst import log
 
-from . import uiutil
+from .lib import uiutil
 from .baseclass import vmmGObjectUI
-from .storagelist import vmmStorageList
+from .hoststorage import vmmHostStorage
 
 
 class vmmStorageBrowser(vmmGObjectUI):
@@ -36,10 +22,7 @@ class vmmStorageBrowser(vmmGObjectUI):
         # Passed to browse_local
         self._browse_reason = None
 
-        # Whether we should abide stable defaults
-        self._stable_defaults = False
-
-        self.storagelist = vmmStorageList(self.conn, self.builder, self.topwin,
+        self.storagelist = vmmHostStorage(self.conn, self.builder, self.topwin,
             self._vol_sensitive_cb)
         self._init_ui()
 
@@ -50,20 +33,20 @@ class vmmStorageBrowser(vmmGObjectUI):
 
 
     def show(self, parent):
-        logging.debug("Showing storage browser")
+        log.debug("Showing storage browser")
         if not self._first_run:
             self._first_run = True
             pool = self.conn.get_default_pool()
-            uiutil.set_list_selection(self.storagelist.widget("pool-list"),
-                pool and pool.get_connkey() or None)
+            uiutil.set_list_selection(
+                    self.storagelist.widget("pool-list"), pool)
 
         self.topwin.set_transient_for(parent)
         self.topwin.present()
         self.conn.schedule_priority_tick(pollpool=True)
 
     def close(self, ignore1=None, ignore2=None):
-        if self.topwin.is_visible():
-            logging.debug("Closing storage browser")
+        if self.is_visible():
+            log.debug("Closing storage browser")
             self.topwin.hide()
         self.storagelist.close()
         return 1
@@ -74,19 +57,9 @@ class vmmStorageBrowser(vmmGObjectUI):
         self.storagelist.cleanup()
         self.storagelist = None
 
-
-    ##############
-    # Public API #
-    ##############
-
-    def set_finish_cb(self, callback):
-        self._finish_cb = callback
-    def set_browse_reason(self, reason):
-        self._browse_reason = reason
-    def set_vm_name(self, name):
-        self.storagelist.set_name_hint(name)
-    def set_stable_defaults(self, val):
-        self._stable_defaults = val
+    ###########
+    # UI init #
+    ###########
 
     def _init_ui(self):
         self.storagelist.connect("browse-clicked", self._browse_clicked)
@@ -116,12 +89,28 @@ class vmmStorageBrowser(vmmGObjectUI):
         self.storagelist.widget("choose-volume").set_sensitive(False)
         self.storagelist.widget("pool-apply").set_visible(False)
 
-        data = self.config.browse_reason_data.get(self._browse_reason)
-        allow_create = True
-        if data:
-            self.topwin.set_title(data["storage_title"])
-            allow_create = data["enable_create"]
+        self.set_browse_reason(self._browse_reason)
 
+
+    ##############
+    # Public API #
+    ##############
+
+    def set_finish_cb(self, callback):
+        self._finish_cb = callback
+    def set_vm_name(self, name):
+        self.storagelist.set_name_hint(name)
+
+    def set_browse_reason(self, reason):
+        self._browse_reason = reason
+        data = self.config.browse_reason_data.get(self._browse_reason, {})
+        allow_create = True
+        title = _("Choose Storage Volume")
+        if data:
+            allow_create = data["enable_create"]
+            title = data["storage_title"]
+
+        self.topwin.set_title(title)
         self.storagelist.widget("vol-add").set_sensitive(allow_create)
 
 
@@ -135,16 +124,13 @@ class vmmStorageBrowser(vmmGObjectUI):
 
     def _volume_chosen(self, src, volume):
         ignore = src
-        logging.debug("Chosen volume XML:\n%s", volume.xmlobj.get_xml_config())
+        log.debug("Chosen volume XML:\n%s", volume.xmlobj.get_xml())
         self._finish(volume.get_target_path())
 
     def _vol_sensitive_cb(self, fmt):
         if ((self._browse_reason == self.config.CONFIG_DIR_FS) and
             fmt != 'dir'):
             return False
-        elif self._stable_defaults:
-            if fmt == "vmdk":
-                return False
         return True
 
 
@@ -167,7 +153,7 @@ class vmmStorageBrowser(vmmGObjectUI):
             dialog_type=dialog_type, browse_reason=self._browse_reason,
             dialog_name=dialog_name, choose_button=choose_button)
         if filename:
-            logging.debug("Browse local chose path=%s", filename)
+            log.debug("Browse local chose path=%s", filename)
             self._finish(filename)
 
     def _finish(self, path):
